browser Package — Products.DCWorkflow 2.4.0.dev0 documentation

# browser Package

## `browser` Package

DCWorkflow browser views.

## `workflow` Module

DCWorkflowDefinition browser views.

class `Products.DCWorkflow.browser.workflow.` `DCWorkflowDefinitionAddView`

  Bases: `Products.GenericSetup.browser.utils.AddWithPresettingsViewBase`

  Add view for DCWorkflowDefinition.

  `description` = u'Add a web-configurable workflow.'
  `getProfileInfos`()
  `klass`

    alias of `DCWorkflowDefinition`